Overview — django_dicom 0.1.0 documentation

# Overview

django_dicom is a reusable Django application built to maintain a database of DICOM data. It was created to support the pylabber project, but does not depend on it. django_dicom creates models that represent the various DICOM entities: `Image`, `Series`, `Study`, and `Patient` (see here and here for more information) and provides utility methods to import data and easily maintain the DICOM entities and their relationship. Once data is imported, Django’s ORM provides us with powerful querying abilities.

The purposed of this reusable Django application is to create a centralized solution for DICOM data management in the context of of academic research. It is being written as a local solution for Tel Aviv University’s neuroimaging lab.